==> PEAR_2600_X64_LINUX_1.0.0.tar.gz: etc/router/scripts/start_wan.sh <==
#!/bin/bash

cfgfile_wan_method=/etc/router/config/wan_method.json
cfgfile_wan=
netcard_wan=eth0
account_file=/etc/router/tmp/account_list.txt

wan_start_lan() {
	proc=`ps -ef | grep dnsmasq | grep -v grep | awk '{print $2}'`
	if [[ -z ${proc} ]]; then
		nohup /etc/router/scripts/start_lan.sh > /dev/null 2>&1  &
	fi
	proc=`ps -ef | grep hostapd | grep -v grep | awk '{print $2}'`
	if [[ -z ${proc} ]]; then
		nohup /etc/router/scripts/start_wireless_5g.sh > /dev/null 2>&1  &
		nohup /etc/router/scripts/start_wireless_2g.sh > /dev/null 2>&1  &
	fi
}

wan_stop_lan() {
	proc=`ps -ef | grep dnsmasq | grep -v grep | awk '{print $2}'`
	if [[ -n ${proc} ]]; then
		kill -9 ${proc}
	fi
	proc=`ps -ef | grep hostapd | grep -v grep | awk '{print $2}'`
	if [[ -n ${proc} ]]; then
		kill -9 ${proc}
	fi
}

wan_stop_pppd() {
	proc=`ps -ef | grep pppd | grep -v grep | awk '{print $2}'`
	if [[ -n ${proc} ]]; then
		kill -9 ${proc}
		sleep 0.5
	fi
}

wan_dns_manual() {
	dns_manual=`cat ${cfgfile_wan} | jq -r .dns_manual`

	if [[ ${dns_manual} == 1 ]]; then
		dns1=`cat ${cfgfile_wan} | jq -r .dns1`
		dns2=`cat ${cfgfile_wan} | jq -r .dns2`
		echo "nameserver ${dns1}" > /etc/resolv.conf
		echo "nameserver ${dns2}" >> /etc/resolv.conf
	else
		echo "nameserver 127.0.0.53" > /etc/resolv.conf
	fi
}

wan_create_br0() {
	cfgfile_gateway=/etc/router/config/lan_gateway.json
	lan_gateway=`cat ${cfgfile_gateway} | jq -r .ipaddr`
	lan_netmask=`cat ${cfgfile_gateway} | jq -r .netmask`
	
	br_if=`ifconfig | grep br0:`
	if [[ -z ${br_if} ]]; then
		brctl addbr br0
		brctl addif br0 eth1
		brctl addif br0 eth2
		brctl addif br0 eth3
		brctl addif br0 eth4
		brctl addif br0 eth5
		ifconfig eth1 0.0.0.0 up
		ifconfig eth2 0.0.0.0 up
		ifconfig eth3 0.0.0.0 up
		ifconfig eth4 0.0.0.0 up
		ifconfig eth5 0.0.0.0 up
		ifconfig br0 ${lan_gateway} netmask ${lan_netmask} up

		lan_segment=`ip route | grep br0 | awk '{print $1}' | head -1`
		iptables -A FORWARD -o br0 -j ACCEPT
		iptables -A FORWARD -i br0 -j ACCEPT
		iptables -t nat -A POSTROUTING -s ${lan_segment} ! -o br0 -j MASQUERADE
	fi

	if [[ ${setup} == 6 ]]; then
		brctl addif br0 ${netcard_wan}
	else
		brctl delif br0 ${netcard_wan}
	fi

}

wan_pppoe_dial() {
	cfgfile_wan=/etc/router/config/wan_pppoe_dial.json
	netcard=${netcard_wan}
	username=`cat ${cfgfile_wan} | jq -r .username`
	password=`cat ${cfgfile_wan} | jq -r .password`

	cat > /etc/ppp/options.prfile << EOF
noauth
refuse-eap
user '${username}'
password '${password}'
plugin rp-pppoe.so ${netcard}
mru 1492 mtu 1492
persist
holdoff 10
maxfail 0
usepeerdns
ipcp-accept-remote ipcp-accept-local noipdefault
ktune
default-asyncmap nopcomp noaccomp
novj nobsdcomp nodeflate
lcp-echo-interval 6
lcp-echo-failure 10
lcp-echo-adaptive
unit 1
linkname prfile0
EOF

	pppd file /etc/ppp/options.prfile
	wan_dns_manual
	wan_create_br0
	wan_start_lan
}

wan_pppoe_multidial() {
	cfgfile_wan=/etc/router/config/wan_pppoe_multidial.json
	vlan_enabled=`cat ${cfgfile_wan} | jq -r .vlan_enabled`
	cat ${cfgfile_wan} | jq -r .account_list > ${account_file}

	docker ps -a
	mac=`ifconfig docker0 | grep ether | awk '{print $2}'`
	n=0
	netcard=${netcard_wan}
	while read line; do
		ac=` echo ${line} | awk '{print $1}' `
		pw=` echo ${line} | awk '{print $2}' `
		if [[ ${vlan_enabled} == 1 ]]; then
			vlan=` echo ${line} | awk '{print $3}' `
			vlanif=${netcard}.${vlan}
			pppif=veth${n}
			macvlan="${mac:0:8}:`openssl rand -hex 3 | sed 's/\(..\)/\1:/g; s/.$//'` "
			cmd=` cat /etc/network/interfaces | grep ${vlanif} | head -n 1 | awk '{print $2}'`
			if [ -z $cmd ]; then
				cat >> /etc/network/interfaces << EOF
auto ${vlanif}
iface ${vlanif} inet manual
pre-up ifconfig ${vlanif} hw ether ${macvlan}
EOF
				vconfig add ${netcard} ${vlan}
			fi
			ip link delete ${pppif}
			ip link add link ${vlanif} name ${pppif} type macvlan
			ip link set ${pppif} up
		else
			pppif=${netcard}
		fi
		cat > /etc/ppp/options.prfile${n} << EOF
noauth
refuse-eap
user '${ac}'
password '${pw}'
plugin rp-pppoe.so ${pppif}
mru 1492 mtu 1492
persist
holdoff 10
maxfail 0
usepeerdns
ipcp-accept-remote ipcp-accept-local noipdefault
ktune
default-asyncmap nopcomp noaccomp
novj nobsdcomp nodeflate
lcp-echo-interval 6
lcp-echo-failure 10
lcp-echo-adaptive
unit $((n+1))
linkname prfile${n}
EOF
		pppd file /etc/ppp/options.prfile${n}
		sleep 1
		let n+=1
	done < ${account_file}

	wan_dns_manual
	wan_create_br0
	wan_start_lan
}

wan_pppoe_multiwan() {
	cfgfile_wan=/etc/router/config/wan_pppoe_multiwan.json
	vlan_enabled=`cat ${cfgfile_wan} | jq -r .vlan_enabled`
	cat ${cfgfile_wan} | jq -r .account_list > ${account_file}

	docker ps -a
	mac=`ifconfig docker0 | grep ether | awk '{print $2}'`
	n=0
	netcard=
	pppif=
	while read line; do
		ac=` echo ${line} | awk '{print $1}' `
		pw=` echo ${line} | awk '{print $2}' `
		netcard=` echo $line | awk '{print $3}' `
		if [[ ${vlan_enabled} == 1 ]]; then
			vlan=` echo ${line} | awk '{print $4}' `
			vlanif=${netcard}.${vlan}
			pppif=veth${n}
			macvlan="${mac:0:8}:`openssl rand -hex 3 | sed 's/\(..\)/\1:/g; s/.$//'` "
			cmd=` cat /etc/network/interfaces | grep ${vlanif} | head -n 1 | awk '{print $2}'`
			if [ -z ${cmd} ]; then
				cat >> /etc/network/interfaces << EOF
auto ${vlanif}
iface ${vlanif} inet manual
pre-up ifconfig ${vlanif} hw ether ${macvlan}
EOF
				vconfig add ${netcard} ${vlan}
			fi
			ip link delete ${pppif}
			ip link add link ${vlanif} name ${pppif} type macvlan
			ip link set ${pppif} up
		else
			pppif=${netcard}
		fi
		cat > /etc/ppp/options.prfile${n} << EOF
noauth
refuse-eap
user '${ac}'
password '${pw}'
plugin rp-pppoe.so ${pppif}
mru 1492 mtu 1492
persist
holdoff 10
maxfail 0
usepeerdns
ipcp-accept-remote ipcp-accept-local noipdefault
ktune
default-asyncmap nopcomp noaccomp
novj nobsdcomp nodeflate
lcp-echo-interval 6
lcp-echo-failure 10
lcp-echo-adaptive
unit $((n+1))
linkname prfile${n}
EOF
		pppd file /etc/ppp/options.prfile${n}
		sleep 1
		let n+=1
	done < ${account_file}

	wan_dns_manual
	wan_create_br0
	wan_start_lan
}

wan_dhcp() {
	cfgfile_wan=/etc/router/config/wan_dhcp.json
	netcard=${netcard_wan}
	ip addr flush dev ${netcard}
	dhclient ${netcard}
	wan_dns_manual
	wan_create_br0
	wan_start_lan
}

wan_static() {
	cfgfile_wan=/etc/router/config/wan_static.json
	netcard=${netcard_wan}
	addr=`cat ${cfgfile_wan} | jq -r .ipaddr`
	mask=`cat ${cfgfile_wan} | jq -r .netmask`
	gateway=`cat ${cfgfile_wan} | jq -r .gateway`
	dns1=`cat ${cfgfile_wan} | jq -r .dns1`
	dns2=`cat ${cfgfile_wan} | jq -r .dns2`
	ifconfig ${netcard} ${addr} netmask ${mask}
	ip route add ${gateway} dev ${netcard}
	ip route del default
	ip route add default via ${gateway} dev ${netcard}
	#wan_dns_manual
	echo "nameserver ${dns1}" > /etc/resolv.conf
	echo "nameserver ${dns2}" >> /etc/resolv.conf
	wan_create_br0
	wan_start_lan
}

wan_bridge() {
	cfgfile_wan=/etc/router/config/wan_bridge.json
	wan_create_br0
	wan_stop_lan
}

wan_stop_pppd
setup=`cat ${cfgfile_wan_method} | jq -r .setup`
case "${setup}" in
  1)
    wan_pppoe_dial
    ;;
  2)
    wan_pppoe_multidial
    ;;
  3)
    wan_pppoe_multiwan
    ;;
  4)
    wan_dhcp
    ;;
  5)
    wan_static
    ;;
  6)
    wan_bridge
    ;;
  *)
    exit 1
esac

exit 0

==> PEAR_2600_X64_LINUX_1.0.1.tar.gz: etc/router/scripts/start_wan.sh <==
#!/bin/bash

netcard_wan=eth0
cfgfile_wan=
account_file=/etc/router/run/account_list.txt

wan_start_lan() {
	proc=`ps -ef | grep dnsmasq | grep -v grep | awk '{print $2}'`
	if [[ -z ${proc} ]]; then
		nohup /etc/router/scripts/start_lan.sh > /dev/null 2>&1  &
	fi
	proc=`ps -ef | grep hostapd | grep -v grep | awk '{print $2}'`
	if [[ -z ${proc} ]]; then
		nohup /etc/router/scripts/start_wireless_5g.sh > /dev/null 2>&1  &
		nohup /etc/router/scripts/start_wireless_2g.sh > /dev/null 2>&1  &
	fi
}

wan_stop_lan() {
	proc=`ps -ef | grep dnsmasq | grep -v grep | awk '{print $2}'`
	if [[ -n ${proc} ]]; then
		kill -9 ${proc}
	fi
	proc=`ps -ef | grep hostapd | grep -v grep | awk '{print $2}'`
	if [[ -n ${proc} ]]; then
		kill -9 ${proc}
	fi
}

wan_stop_pppd() {
	proc=`ps -ef | grep pppd | grep -v grep | awk '{print $2}'`
	if [[ -n ${proc} ]]; then
		kill -9 ${proc}
		sleep 0.5
	fi
}

wan_stop_wireless() {
	netcard=wlan0
	proc=`ps -ef | grep "${netcard}" | grep -v grep | awk '{print $2}'`
	if [[ -n ${proc} ]]; then
		kill -9 ${proc}
		sleep 0.5
	fi
	proc=`ps -ef | grep hostapd | grep -v grep | awk '{print $2}'`
	if [[ -n ${proc} ]]; then
		kill -9 ${proc}
		sleep 0.5
	fi
	proc=`ps -ef | grep wpa_supplicant | grep -v grep | awk '{print $2}'`
	if [[ -n ${proc} ]]; then
		kill -9 ${proc}
		sleep 0.5
	fi

	systemctl stop wpa_supplicant
	ifconfig ${netcard} down
	ifconfig ${netcard} 0.0.0.0
	brctl delif br0 ${netcard}
	ap_exist=`ls /sys/class/net/ | grep ${netcard}-ap`
	if [[ -n ${ap_exist} ]]; then
		iw dev ${netcard}-ap del
		sleep 0.5
	fi
}

wan_dns_manual() {
	dns_manual=`cat ${cfgfile_wan} | jq -r .dns_manual`

	if [[ ${dns_manual} == 1 ]]; then
		dns1=`cat ${cfgfile_wan} | jq -r .dns1`
		dns2=`cat ${cfgfile_wan} | jq -r .dns2`
		echo "nameserver ${dns1}" > /etc/resolv.conf
		echo "nameserver ${dns2}" >> /etc/resolv.conf
	else
		echo "nameserver 127.0.0.53" > /etc/resolv.conf
	fi
}

wan_create_br0() {
	cfgfile_gateway=/etc/router/config/lan_gateway.json
	lan_gateway=`cat ${cfgfile_gateway} | jq -r .ipaddr`
	lan_netmask=`cat ${cfgfile_gateway} | jq -r .netmask`
	
	br_if=`ifconfig | grep br0:`
	if [[ -z ${br_if} ]]; then
		brctl addbr br0
		brctl addif br0 eth1
		brctl addif br0 eth2
		brctl addif br0 eth3
		#brctl addif br0 eth4
		#brctl addif br0 eth5
		ifconfig eth1 0.0.0.0 up
		ifconfig eth2 0.0.0.0 up
		ifconfig eth3 0.0.0.0 up
		#ifconfig eth4 0.0.0.0 up
		#ifconfig eth5 0.0.0.0 up
		ifconfig br0 ${lan_gateway} netmask ${lan_netmask} up

		lan_segment=`ip route | grep br0 | awk '{print $1}' | head -1`
		iptables -A FORWARD -o br0 -j ACCEPT
		iptables -A FORWARD -i br0 -j ACCEPT
		iptables -t nat -A POSTROUTING -s ${lan_segment} ! -o br0 -j MASQUERADE
	fi

	if [[ ${setup} == 6 ]]; then
		brctl addif br0 ${netcard_wan}
	else
		brctl delif br0 ${netcard_wan}
	fi
}

wan_pppoe_dial() {
	cfgfile_wan=/etc/router/config/wan_pppoe_dial.json
	netcard=${netcard_wan}
	username=`cat ${cfgfile_wan} | jq -r .username`
	password=`cat ${cfgfile_wan} | jq -r .password`

	cat > /etc/ppp/options.prfile << EOF
noauth
refuse-eap
user '${username}'
password '${password}'
plugin rp-pppoe.so ${netcard}
mru 1492 mtu 1492
persist
holdoff 10
maxfail 0
usepeerdns
ipcp-accept-remote ipcp-accept-local noipdefault
ktune
default-asyncmap nopcomp noaccomp
novj nobsdcomp nodeflate
lcp-echo-interval 6
lcp-echo-failure 10
lcp-echo-adaptive
unit 1
linkname prfile0
EOF

	pppd file /etc/ppp/options.prfile
	wan_dns_manual
	wan_create_br0
	wan_start_lan
}

wan_pppoe_multidial() {
	cfgfile_wan=/etc/router/config/wan_pppoe_multidial.json
	vlan_enabled=`cat ${cfgfile_wan} | jq -r .vlan_enabled`
	cat ${cfgfile_wan} | jq -r .account_list > ${account_file}

	docker ps -a
	mac=`ifconfig docker0 | grep ether | awk '{print $2}'`
	n=0
	netcard=${netcard_wan}
	while read line; do
		ac=` echo ${line} | awk '{print $1}' `
		pw=` echo ${line} | awk '{print $2}' `
		if [[ ${vlan_enabled} == 1 ]]; then
			vlan=` echo ${line} | awk '{print $3}' `
			vlanif=${netcard}.${vlan}
			pppif=veth${n}
			macvlan="${mac:0:8}:`openssl rand -hex 3 | sed 's/\(..\)/\1:/g; s/.$//'` "
			cmd=` cat /etc/network/interfaces | grep ${vlanif} | head -n 1 | awk '{print $2}'`
			if [ -z $cmd ]; then
				cat >> /etc/network/interfaces << EOF
auto ${vlanif}
iface ${vlanif} inet manual
pre-up ifconfig ${vlanif} hw ether ${macvlan}
EOF
				vconfig add ${netcard} ${vlan}
			fi
			ip link delete ${pppif}
			ip link add link ${vlanif} name ${pppif} type macvlan
			ip link set ${pppif} up
		else
			pppif=${netcard}
		fi
		cat > /etc/ppp/options.prfile${n} << EOF
noauth
refuse-eap
user '${ac}'
password '${pw}'
plugin rp-pppoe.so ${pppif}
mru 1492 mtu 1492
persist
holdoff 10
maxfail 0
usepeerdns
ipcp-accept-remote ipcp-accept-local noipdefault
ktune
default-asyncmap nopcomp noaccomp
novj nobsdcomp nodeflate
lcp-echo-interval 6
lcp-echo-failure 10
lcp-echo-adaptive
unit $((n+1))
linkname prfile${n}
EOF
		pppd file /etc/ppp/options.prfile${n}
		sleep 1
		let n+=1
	done < ${account_file}

	wan_dns_manual
	wan_create_br0
	wan_start_lan
}

wan_pppoe_multiwan() {
	cfgfile_wan=/etc/router/config/wan_pppoe_multiwan.json
	vlan_enabled=`cat ${cfgfile_wan} | jq -r .vlan_enabled`
	cat ${cfgfile_wan} | jq -r .account_list > ${account_file}

	docker ps -a
	mac=`ifconfig docker0 | grep ether | awk '{print $2}'`
	n=0
	netcard=
	pppif=
	while read line; do
		ac=` echo ${line} | awk '{print $1}' `
		pw=` echo ${line} | awk '{print $2}' `
		netcard=` echo $line | awk '{print $3}' `
		if [[ ${vlan_enabled} == 1 ]]; then
			vlan=` echo ${line} | awk '{print $4}' `
			vlanif=${netcard}.${vlan}
			pppif=veth${n}
			macvlan="${mac:0:8}:`openssl rand -hex 3 | sed 's/\(..\)/\1:/g; s/.$//'` "
			cmd=` cat /etc/network/interfaces | grep ${vlanif} | head -n 1 | awk '{print $2}'`
			if [ -z ${cmd} ]; then
				cat >> /etc/network/interfaces << EOF
auto ${vlanif}
iface ${vlanif} inet manual
pre-up ifconfig ${vlanif} hw ether ${macvlan}
EOF
				vconfig add ${netcard} ${vlan}
			fi
			ip link delete ${pppif}
			ip link add link ${vlanif} name ${pppif} type macvlan
			ip link set ${pppif} up
		else
			pppif=${netcard}
		fi
		cat > /etc/ppp/options.prfile${n} << EOF
noauth
refuse-eap
user '${ac}'
password '${pw}'
plugin rp-pppoe.so ${pppif}
mru 1492 mtu 1492
persist
holdoff 10
maxfail 0
usepeerdns
ipcp-accept-remote ipcp-accept-local noipdefault
ktune
default-asyncmap nopcomp noaccomp
novj nobsdcomp nodeflate
lcp-echo-interval 6
lcp-echo-failure 10
lcp-echo-adaptive
unit $((n+1))
linkname prfile${n}
EOF
		pppd file /etc/ppp/options.prfile${n}
		sleep 1
		let n+=1
	done < ${account_file}

	wan_dns_manual
	#wan_create_br0
	#wan_start_lan
}

wan_dhcp() {
	cfgfile_wan=/etc/router/config/wan_dhcp.json
	netcard=${netcard_wan}
	ip addr flush dev ${netcard}
	nohup /etc/router/scripts/dhcp_get_ip.sh ${netcard} > /dev/null 2>&1  &
	wan_dns_manual
	wan_create_br0
	wan_start_lan
}

wan_static() {
	cfgfile_wan=/etc/router/config/wan_static.json
	netcard=${netcard_wan}
	addr=`cat ${cfgfile_wan} | jq -r .ipaddr`
	mask=`cat ${cfgfile_wan} | jq -r .netmask`
	gateway=`cat ${cfgfile_wan} | jq -r .gateway`
	dns1=`cat ${cfgfile_wan} | jq -r .dns1`
	dns2=`cat ${cfgfile_wan} | jq -r .dns2`
	ifconfig ${netcard} ${addr} netmask ${mask}
	ip route add ${gateway} dev ${netcard}
	ip route del default
	ip route add default via ${gateway} dev ${netcard}
	#wan_dns_manual
	echo "nameserver ${dns1}" > /etc/resolv.conf
	echo "nameserver ${dns2}" >> /etc/resolv.conf
	wan_create_br0
	wan_start_lan
}

wan_bridge() {
	cfgfile_wan=/etc/router/config/wan_bridge.json
	wan_create_br0
	wan_stop_lan
}

wan_wireless_repeater() {
	cfgfile_wan=/etc/router/config/wan_wireless_repeater.json
	ssid=`cat ${cfgfile_wan} | jq -r .ssid`
	key=`cat ${cfgfile_wan} | jq -r .key`
	encryption=`cat ${cfgfile_wan} | jq -r .encryption`
	netcard=wlan0
	mac=`ifconfig docker0 | grep ether | awk '{print $2}'`
	mac_ap="${mac:0:8}:`openssl rand -hex 3 | sed 's/\(..\)/\1:/g; s/.$//'` "
	iw dev ${netcard} interface add ${netcard}-ap type managed addr ${mac_ap}
	wpa_supplicant_cfgpath=/etc/router/run/wpa_supplicant.conf
	if [[ ${encryption} == "on" ]]; then
		cat > ${wpa_supplicant_cfgpath} << EOF
ctrl_interface=/var/run/wpa_supplicant
network={
	scan_ssid=1
	ssid="${ssid}"
	psk="${key}"
}
EOF
	else
		cat > ${wpa_supplicant_cfgpath} << EOF
ctrl_interface=/var/run/wpa_supplicant
network={
	scan_ssid=1
	ssid="${ssid}"
	key_mgmt=NONE
}
EOF
	fi
	wpa_supplicant -B -i ${netcard} -c ${wpa_supplicant_cfgpath}
	nohup /etc/router/scripts/dhcp_get_ip.sh ${netcard} > /dev/null 2>&1  &
	wan_create_br0
	wan_start_lan
}

wan_stop_pppd
wan_stop_wireless
cfgfile_wan_method=/etc/router/config/wan_method.json
setup=`cat ${cfgfile_wan_method} | jq -r .setup`
case "${setup}" in
  1)
    wan_pppoe_dial
    ;;
  2)
    wan_pppoe_multidial
    ;;
  3)
    wan_pppoe_multiwan
    ;;
  4)
    wan_dhcp
    ;;
  5)
    wan_static
    ;;
  6)
    wan_bridge
    ;;
  7)
    wan_wireless_repeater
    ;;
  *)
    exit 1
esac

exit 0
